@@ -1,5 +1,5 @@
 /*
- * (GNU Serveez 0.2.0) libserveez.h
+ * (GNU Serveez 0.2.1) libserveez.h
  *
  * Copyright (C) 2011-2012, 2013 Thien-Thi Nguyen
  * Copyright (C) 2000-2003  Stefan Jahn <stefan@lkcc.org>
@@ -517,6 +517,8 @@ struct svz_socket
 
 __BEGIN_DECLS
 
+typedef void (svz_sock_prefree_fn) (const svz_socket_t *);
+SERVEEZ_API void svz_sock_prefree (int addsub, svz_sock_prefree_fn fn);
 SERVEEZ_API int svz_sock_nconnections (void);
 SERVEEZ_API int svz_sock_write (svz_socket_t *, char *, int);
 SERVEEZ_API int svz_sock_printf (svz_socket_t *, const char *, ...);
@@ -1404,4 +1406,4 @@ __END_DECLS
 
 #endif /* not __LIBSERVEEZ_H__ */
 
-/* (GNU Serveez 0.2.0) libserveez.h ends here */
+/* (GNU Serveez 0.2.1) libserveez.h ends here */
